#
# spec file for package gpuvis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define commit a0ca7a9d4a126f0ad382699010cdf15562afc307

Name:           gpuvis
Version:        20230221
Release:        1.1
Summary:        GPU Trace Visualizer
License:        MIT
Group:          Development/Tools/Debuggers
URL:            https://github.com/mikesart/gpuvis
Source0:        https://github.com/mikesart/gpuvis/archive/%{commit}/gpuvis.tar.gz
Patch0:         0001-gpuvis_macro.h-needs-to-include-stdint.h.patch
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  gtk3-devel
BuildRequires:  libSDL2-devel
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  rapidjson-devel
%ifarch %{ix86} x86_64
%if 0%{?suse_version} > 1530
BuildRequires:  intel-gpu-tools-devel
%endif
%endif

%description
Gpuvis is a Linux GPU profiler similar to GPUView on Windows. It is designed to work with trace-cmd captures and help track down Linux gpu and application performance issues.

%prep
%setup -q -n gpuvis-%{commit}
%patch0 -p1

%build
%meson \
%ifarch %{ix86} x86_64
%if 0%{?suse_version} > 1530
  -Duse_i915_perf=true
%endif
%endif

%meson_build

%install
%meson_install

%files
%{_bindir}/gpuvis

%changelog
* Fri Mar 24 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 20230221 (a0ca7a9d4a126f0ad382699010cdf15562afc307)
  * Fix compilation with latest version of igt
  * Fix build using meson and not vendor rapidjson
  * 0001-gpuvis_macro.h-needs-to-include-stdint.h.patch Fix compile error
* Thu Jan 27 2022 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version v0.1 (first proper release)
  * Minor fixes to compile/link on Windows.
  * Fix includes for GCC 7
  * typo prevents execution
  * Fix some unchecked error codes from asprintf (warnings->errors in gcc7)
  * Don't rely on trace-cmd to mount at /sys/kernel/tracing if tracefs is
  * Fix some potential null pointer dereferences
  * gpuvis_trace_utils: Prefer C++11 thread_local vs. __thread
  * gpuvis_trace_utils: Add 'static' to gpuvis_gettime_u64
  * Add a parser that can handle ETW files (extension is etl)
  * Support for ETL gpu events
  * Fixups for the ETL parser
  * fix compilation on non-windows
  * fix sdl2-config argument
  * Include headers for stub compilation
  * Update SteamVR provider GUID
  * Trace block macro c
  * Add 'ltime=' print param to inject event timestamp
  * Allow hash of arbitrary ctx/ringno/seqno
  * Use high-precision vblank timings, if available
  * Integrate i915-perf data into GPUvis by
  * Plot generic trace events and option to plot as step function
  * Add support for importing generic DRM sched timing events.
  * i915-perf fixes for Makefile by
  * Hide intel GPU generated event row when we don't have any
  * I915 perf updates
  * Run trace-cmd-status.sh script from scripts location
  * Don't die() when an unknown trace-cmd options is encountered
  * Allow dtime= on events to tweak their offset.
  * Don't try to access i915-perf data if no file was given
  * i915-perf: add GPU frequency plot
  * add meson build system
  * trace-read: Fix high-prec vblank timestamps
  * i915-perf: set a different default colors to GPU timeline events
  * meson: remove python2
  * Add loading of Linux perf JSON
  * Better i915-perf / tracepoint tracking
  * Improve archive handling
  * Enable Shortcut for gpuvis Desktop Application
* Fri Dec 10 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 20211204 (7f47419470687c7ecbdf086b81f5bafdb05d1bef)
  * Look at all buffers when calculating min_file_ts
* Fri Dec 10 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Only build with intel-gpu-tools-devel on suse_version > 1530
- Only build with i915_perf=true on x86*
* Wed Nov 24 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Add a proper description
* Wed Nov 24 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Initial version 20211124 (commit ff96f19529021991e6cbcc81f026bca658897bd8)
